/*
*      SmoothAlgorithms.mqh  
*  : __\MQL5\Include
*/
//+------------------------------------------------------------------+ 
//|                                                 Momentum_AMA.mq5 | 
//|                             Copyright  2010,   Nikolay Kositsin | 
//|                              Khabarovsk,   farria@mail.redcom.ru | 
//+------------------------------------------------------------------+ 
#property copyright "Copyright  2010, Nikolay Kositsin"
#property link "farria@mail.redcom.ru"
//----   
#property version   "1.00"
//----     
#property indicator_separate_window 
//----   
#property indicator_buffers 1 
//----     
#property indicator_plots   1
//+-----------------------------------+
//|       |
//+-----------------------------------+
//----     
#property indicator_type1   DRAW_HISTOGRAM
//----       - 
#property indicator_color1 BlueViolet
//----   -  
#property indicator_style1  STYLE_SOLID
//----     1
#property indicator_width1  1
//----   
#property indicator_label1  "Momentum_AMA"
//+-----------------------------------+
//|         |
//+-----------------------------------+
enum Applied_price_      //  
  {
   PRICE_CLOSE_ = 1,     // Close
   PRICE_OPEN_,          // Open
   PRICE_HIGH_,          // High
   PRICE_LOW_,           // Low
   PRICE_MEDIAN_,        // Median Price (HL/2)
   PRICE_TYPICAL_,       // Typical Price (HLC/3)
   PRICE_WEIGHTED_,      // Weighted Close (HLCC/4)
   PRICE_SIMPL_,         // Simple Price (OC/2)
   PRICE_QUARTER_,       // Quarted Price (HLOC/4) 
   PRICE_TRENDFOLLOW0_,  // TrendFollow_1 Price 
   PRICE_TRENDFOLLOW1_   // TrendFollow_2 Price 
  };
input int MLength=8;                   //  
input int AMA_Period=9;                //  AMA
input int Fast_MA_Period=2;            //   
input int Slow_MA_Period=30;           //   
input Applied_price_ IPC=PRICE_CLOSE_; //  
/*      ( 1-CLOSE, 2-OPEN, 3-HIGH, 4-LOW, 
  5-MEDIAN, 6-TYPICAL, 7-WEIGHTED, 8-SIMPLE, 9-QUARTER, 10-TRENDFOLLOW, 11-0.5 * TRENDFOLLOW.) */
input double G=2.0;                    // ,     
input int Shift=0;                     //      
//---+
//----  
double MomentumBuffer[];
//+------------------------------------------------------------------+
//   iPriceSeries                                     |
//   iPriceSeriesAlert                                |
//   CMomentum  CAMA                                 |
//+------------------------------------------------------------------+ 
#include <SmoothAlgorithms.mqh>  
//+------------------------------------------------------------------+    
//| Momentum indicator initialization function                       | 
//+------------------------------------------------------------------+  
void OnInit()
  {
//----      
   SetIndexBuffer(0,MomentumBuffer,INDICATOR_DATA);
//----     
   PlotIndexSetInteger(0,PLOT_SHIFT,Shift);
//----      
   PlotIndexSetInteger(0,PLOT_DRAW_BEGIN,0);
//---      DataWindow
   PlotIndexSetString(0,PLOT_LABEL,"Momentum_AMA");
//----   ,      
   PlotIndexSetDouble(0,PLOT_EMPTY_VALUE,EMPTY_VALUE);
//----      
   string shortname;
   StringConcatenate(shortname,"Momentum_AMA( MLength = ",MLength,")");
//---           
   IndicatorSetString(INDICATOR_SHORTNAME,shortname);
//---     
   IndicatorSetInteger(INDICATOR_DIGITS,2);
//----    CMomentum   SmoothAlgorithms.mqh
   CMomentum Mom;
//----       
   Mom.MALengthCheck("MLength", MLength);
   Mom.MALengthCheck("AMA_Period", AMA_Period);
   Mom.MALengthCheck("Fast_MA_Period", Fast_MA_Period);
   Mom.MALengthCheck("Slow_MA_Period", Slow_MA_Period);
//----  
  }
//+------------------------------------------------------------------+  
//| Momentum iteration function                                      | 
//+------------------------------------------------------------------+  
int OnCalculate(const int rates_total,    //       
                const int prev_calculated,//       
                const datetime &time[],
                const double &open[],
                const double &high[],
                const double &low[],
                const double &close[],
                const long &tick_volume[],
                const long &volume[],
                const int &spread[])
  {
//----       
   if(rates_total<MLength+AMA_Period+1) return(0);

//----       
   double price,momentum,amomentum;
//----        
   int first,bar;

//----    first    
   if(prev_calculated==0)        //      
      first=0;                   //      
   else first=prev_calculated-1; //      

//----    CMomentum  CAMA   SmoothAlgorithms.mqh
   static CMomentum Mom;
   static CAMA AMA;

//----    
   for(bar=first; bar<rates_total; bar++)
     {
      //----   PriceSeries      dprice_
      price=PriceSeries(IPC,bar,open,low,high,close);

      //----  
      momentum=Mom.MomentumSeries(0,prev_calculated,rates_total,MLength,price,bar,false);
      amomentum=AMA.AMASeries(MLength+1,prev_calculated,rates_total,AMA_Period,Fast_MA_Period,Slow_MA_Period,G,momentum,bar,false);

      //----      
      MomentumBuffer[bar]=amomentum/_Point;

     }
//----     
   return(rates_total);
  }
//+------------------------------------------------------------------+
